==> kde-l10n-pl-4.2.4-noarch-1.txz: install/doinst.sh <==
( cd usr/share/doc/HTML/pl/kwordquiz ; rm -rf common )
( cd usr/share/doc/HTML/pl/kwordquiz ; ln -sf /usr/share/doc/HTML/pl//common common )
( cd usr/share/doc/HTML/pl/kmix ; rm -rf common )
( cd usr/share/doc/HTML/pl/kmix ; ln -sf /usr/share/doc/HTML/pl//common common )
( cd usr/share/doc/HTML/pl/kturtle ; rm -rf common )
( cd usr/share/doc/HTML/pl/kturtle ; ln -sf /usr/share/doc/HTML/pl//common common )
( cd usr/share/doc/HTML/pl/kbruch ; rm -rf common )
( cd usr/share/doc/HTML/pl/kbruch ; ln -sf /usr/share/doc/HTML/pl//common common )
( cd usr/share/doc/HTML/pl/kcontrol/kcontrol ; rm -rf common )
( cd usr/share/doc/HTML/pl/kcontrol/kcontrol ; ln -sf /usr/share/doc/HTML/pl//common common )
( cd usr/share/doc/HTML/pl/ark ; rm -rf common )
( cd usr/share/doc/HTML/pl/ark ; ln -sf /usr/share/doc/HTML/pl//common common )
( cd usr/share/doc/HTML/pl/killbots ; rm -rf common )
( cd usr/share/doc/HTML/pl/killbots ; ln -sf /usr/share/doc/HTML/pl//common common )
( cd usr/share/doc/HTML/pl/ktuberling ; rm -rf common )
( cd usr/share/doc/HTML/pl/ktuberling ; ln -sf /usr/share/doc/HTML/pl//common common )
( cd usr/share/doc/HTML/pl/kdepasswd ; rm -rf common )
( cd usr/share/doc/HTML/pl/kdepasswd ; ln -sf /usr/share/doc/HTML/pl//common common )
( cd usr/share/doc/HTML/pl/ktouch ; rm -rf common )
( cd usr/share/doc/HTML/pl/ktouch ; ln -sf /usr/share/doc/HTML/pl//common common )
( cd usr/share/doc/HTML/pl/klettres ; rm -rf common )
( cd usr/share/doc/HTML/pl/klettres ; ln -sf /usr/share/doc/HTML/pl//common common )
( cd usr/share/doc/HTML/pl/ksnapshot ; rm -rf common )
( cd usr/share/doc/HTML/pl/ksnapshot ; ln -sf /usr/share/doc/HTML/pl//common common )
( cd usr/share/doc/HTML/pl/kollision ; rm -rf common )
( cd usr/share/doc/HTML/pl/kollision ; ln -sf /usr/share/doc/HTML/pl//common common )
( cd usr/share/doc/HTML/pl/kwallet ; rm -rf common )
( cd usr/share/doc/HTML/pl/kwallet ; ln -sf /usr/share/doc/HTML/pl//common common )
( cd usr/share/doc/HTML/pl/marble ; rm -rf common )
( cd usr/share/doc/HTML/pl/marble ; ln -sf /usr/share/doc/HTML/pl//common common )
( cd usr/share/doc/HTML/pl/gwenview ; rm -rf common )
( cd usr/share/doc/HTML/pl/gwenview ; ln -sf /usr/share/doc/HTML/pl//common common )
( cd usr/share/doc/HTML/pl/khelpcenter/faq ; rm -rf common )
( cd usr/share/doc/HTML/pl/khelpcenter/faq ; ln -sf /usr/share/doc/HTML/pl//common common )
( cd usr/share/doc/HTML/pl/khelpcenter/userguide ; rm -rf common )
( cd usr/share/doc/HTML/pl/khelpcenter/userguide ; ln -sf /usr/share/doc/HTML/pl//common common )
( cd usr/share/doc/HTML/pl/khelpcenter/visualdict ; rm -rf common )
( cd usr/share/doc/HTML/pl/khelpcenter/visualdict ; ln -sf /usr/share/doc/HTML/pl//common common )
( cd usr/share/doc/HTML/pl/khelpcenter/quickstart ; rm -rf common )
( cd usr/share/doc/HTML/pl/khelpcenter/quickstart ; ln -sf /usr/share/doc/HTML/pl//common common )
( cd usr/share/doc/HTML/pl/kscd ; rm -rf common )
( cd usr/share/doc/HTML/pl/kscd ; ln -sf /usr/share/doc/HTML/pl//common common )

==> kde-l10n-pl-4.3.1-noarch-1.txz: install/doinst.sh <==
( cd usr/share/doc/HTML/pl/ark ; rm -rf common )
( cd usr/share/doc/HTML/pl/ark ; ln -sf /usr/share/doc/HTML/pl//common common )
( cd usr/share/doc/HTML/pl/ktuberling ; rm -rf common )
( cd usr/share/doc/HTML/pl/ktuberling ; ln -sf /usr/share/doc/HTML/pl//common common )
( cd usr/share/doc/HTML/pl/amor ; rm -rf common )
( cd usr/share/doc/HTML/pl/amor ; ln -sf /usr/share/doc/HTML/pl//common common )
( cd usr/share/doc/HTML/pl/kmix ; rm -rf common )
( cd usr/share/doc/HTML/pl/kmix ; ln -sf /usr/share/doc/HTML/pl//common common )
( cd usr/share/doc/HTML/pl/kmail ; rm -rf common )
( cd usr/share/doc/HTML/pl/kmail ; ln -sf /usr/share/doc/HTML/pl//common common )
( cd usr/share/doc/HTML/pl/ksnapshot ; rm -rf common )
( cd usr/share/doc/HTML/pl/ksnapshot ; ln -sf /usr/share/doc/HTML/pl//common common )
( cd usr/share/doc/HTML/pl/lilo-config ; rm -rf common )
( cd usr/share/doc/HTML/pl/lilo-config ; ln -sf /usr/share/doc/HTML/pl//common common )
( cd usr/share/doc/HTML/pl/khelpcenter/faq ; rm -rf common )
( cd usr/share/doc/HTML/pl/khelpcenter/faq ; ln -sf /usr/share/doc/HTML/pl//common common )
( cd usr/share/doc/HTML/pl/khelpcenter/quickstart ; rm -rf common )
( cd usr/share/doc/HTML/pl/khelpcenter/quickstart ; ln -sf /usr/share/doc/HTML/pl//common common )
( cd usr/share/doc/HTML/pl/khelpcenter/visualdict ; rm -rf common )
( cd usr/share/doc/HTML/pl/khelpcenter/visualdict ; ln -sf /usr/share/doc/HTML/pl//common common )
( cd usr/share/doc/HTML/pl/kwallet ; rm -rf common )
( cd usr/share/doc/HTML/pl/kwallet ; ln -sf /usr/share/doc/HTML/pl//common common )
( cd usr/share/doc/HTML/pl/kbruch ; rm -rf common )
( cd usr/share/doc/HTML/pl/kbruch ; ln -sf /usr/share/doc/HTML/pl//common common )
( cd usr/share/doc/HTML/pl/kollision ; rm -rf common )
( cd usr/share/doc/HTML/pl/kollision ; ln -sf /usr/share/doc/HTML/pl//common common )
( cd usr/share/doc/HTML/pl/ktouch ; rm -rf common )
( cd usr/share/doc/HTML/pl/ktouch ; ln -sf /usr/share/doc/HTML/pl//common common )
( cd usr/share/doc/HTML/pl/klettres ; rm -rf common )
( cd usr/share/doc/HTML/pl/klettres ; ln -sf /usr/share/doc/HTML/pl//common common )
( cd usr/share/doc/HTML/pl/kwatchgnupg ; rm -rf common )
( cd usr/share/doc/HTML/pl/kwatchgnupg ; ln -sf /usr/share/doc/HTML/pl//common common )
( cd usr/share/doc/HTML/pl/kteatime ; rm -rf common )
( cd usr/share/doc/HTML/pl/kteatime ; ln -sf /usr/share/doc/HTML/pl//common common )
( cd usr/share/doc/HTML/pl/gwenview ; rm -rf common )
( cd usr/share/doc/HTML/pl/gwenview ; ln -sf /usr/share/doc/HTML/pl//common common )
( cd usr/share/doc/HTML/pl/kwordquiz ; rm -rf common )
( cd usr/share/doc/HTML/pl/kwordquiz ; ln -sf /usr/share/doc/HTML/pl//common common )
